@@ -14,6 +14,11 @@ if 'django_select2' in settings.INSTALLED_APPS:
                     return True
                 return False
 
+            def prepare_value(self, value):
+                if not value:
+                    return None
+                return super(PageSearchField, self).prepare_value(value)
+
         class UserSearchField(AutoModelSelect2Field):
             search_fields = ['username__icontains', 'firstname__icontains', 'lastname__icontains']
 
@@ -22,6 +27,12 @@ if 'django_select2' in settings.INSTALLED_APPS:
                 if user and not user.is_anonymous() and user.is_staff:
                     return True
                 return False
+
+            def prepare_value(self, value):
+                if not value:
+                    return None
+                return super(PageSearchField, self).prepare_value(value)
+
     except ImportError:
         pass
 
